@@ -2,7 +2,7 @@
 ## Reader
 
 getReaders <- function()
-    c("readDOC", "readGmane", "readPDF", "readReut21578XML", "readReut21578XMLasPlain", "readPlain", "readRCV1", "readTabular")
+    c("readDOC", "readGmane", "readPDF", "readReut21578XML", "readReut21578XMLasPlain", "readPlain", "readRCV1", "readRCV1asPlain", "readTabular")
 
 prepareReader <- function(readerControl, defaultReader = NULL, ...) {
     if (is.null(readerControl$reader))
@@ -56,7 +56,11 @@ readReut21578XML <- readXML(spec = list(Author = list("node", "/REUTERS/TEXT/AUT
                             Heading = list("node", "/REUTERS/TEXT/TITLE"),
                             ID = list("attribute", "/REUTERS/@NEWID"),
                             Origin = list("unevaluated", "Reuters-21578 XML"),
-                            Topics = list("node", "/REUTERS/TOPICS/D")),
+                            Topics = list("node", "/REUTERS/TOPICS/D"),
+                            Places = list("node", "/REUTERS/PLACES/D"),
+                            People = list("node", "/REUTERS/PEOPLE/D"),
+                            Orgs = list("node", "/REUTERS/ORGS/D"),
+                            Exchanges = list("node", "/REUTERS/EXCHANGES/D")),
                             doc = Reuters21578Document())
 
 readReut21578XMLasPlain <- readXML(spec = list(Author = list("node", "/REUTERS/TEXT/AUTHOR"),
@@ -69,7 +73,11 @@ readReut21578XMLasPlain <- readXML(spec = list(Author = list("node", "/REUTERS/T
                                    Heading = list("node", "/REUTERS/TEXT/TITLE"),
                                    ID = list("attribute", "/REUTERS/@NEWID"),
                                    Origin = list("unevaluated", "Reuters-21578 XML"),
-                                   Topics = list("node", "/REUTERS/TOPICS/D")),
+                                   Topics = list("node", "/REUTERS/TOPICS/D"),
+                                   Places = list("node", "/REUTERS/PLACES/D"),
+                                   People = list("node", "/REUTERS/PEOPLE/D"),
+                                   Orgs = list("node", "/REUTERS/ORGS/D"),
+                                   Exchanges = list("node", "/REUTERS/EXCHANGES/D")),
                                    doc = PlainTextDocument())
 
 readRCV1 <- readXML(spec = list(Author = list("unevaluated", ""),
@@ -78,11 +86,27 @@ readRCV1 <- readXML(spec = list(Author = list("unevaluated", ""),
                     Description = list("unevaluated", ""),
                     Heading = list("node", "/newsitem/title"),
                     ID = list("attribute", "/newsitem/@itemid"),
-                    Origin = list("unevaluated", "Reuters Corpus Volume 1 XML"),
+                    Origin = list("unevaluated", "Reuters Corpus Volume 1"),
                     Publisher = list("attribute", "/newsitem/metadata/dc[@element='dc.publisher']/@value"),
-                    Topics = list("attribute", "/newsitem/metadata/codes[@class='bip:topics:1.0']/code/@code")),
+                    Topics = list("attribute", "/newsitem/metadata/codes[@class='bip:topics:1.0']/code/@code"),
+                    Industries = list("attribute", "/newsitem/metadata/codes[@class='bip:industries:1.0']/code/@code"),
+                    Countries = list("attribute", "/newsitem/metadata/codes[@class='bip:countries:1.0']/code/@code")),
                     doc = RCV1Document())
 
+readRCV1asPlain <- readXML(spec = list(Author = list("unevaluated", ""),
+                           Content = list("node", "/newsitem/text"),
+                           DateTimeStamp = list("function", function(node)
+                           as.POSIXlt(as.character(XML::getNodeSet(node, "/newsitem/@date")), tz = "GMT")),
+                           Description = list("unevaluated", ""),
+                           Heading = list("node", "/newsitem/title"),
+                           ID = list("attribute", "/newsitem/@itemid"),
+                           Origin = list("unevaluated", "Reuters Corpus Volume 1"),
+                           Publisher = list("attribute", "/newsitem/metadata/dc[@element='dc.publisher']/@value"),
+                           Topics = list("attribute", "/newsitem/metadata/codes[@class='bip:topics:1.0']/code/@code"),
+                           Industries = list("attribute", "/newsitem/metadata/codes[@class='bip:industries:1.0']/code/@code"),
+                           Countries = list("attribute", "/newsitem/metadata/codes[@class='bip:countries:1.0']/code/@code")),
+                           doc = PlainTextDocument())
+
 # # readDOC needs antiword installed to be able to extract the text
 readDOC <- FunctionGenerator(function(AntiwordOptions = "", ...) {
     AntiwordOptions <- AntiwordOptions
